# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from public_api_server_connector_v2.models.content import Content
from public_api_server_connector_v2.models.content_block_type_str_enum import ContentBlockTypeStrEnum
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class ContentBlockPatch(BaseModel):
    """
    ContentBlockPatch
    """ # noqa: E501
    id: StrictInt = Field(description="ID of the content block to update")
    block_type: Optional[ContentBlockTypeStrEnum] = Field(default=None, description="Type of the content block. If not set, it will be not updated")
    order: Optional[StrictInt] = Field(default=None, description="Order of the content block in the lesson. If not set, it will be not updated")
    is_expanded: Optional[StrictBool] = Field(default=None, description="Whether the content block is expanded or collapsed by default, only applicable for text and HTML blocks. If not set, it will be not updated")
    content: Optional[Content] = Field(default=None, description="Content of the block. If not set, it will be not updated")
    __properties: ClassVar[List[str]] = ["id", "block_type", "order", "is_expanded", "content"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ContentBlockPatch from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of content
        if self.content:
            _dict['content'] = self.content.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ContentBlockPatch from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "block_type": obj.get("block_type"),
            "order": obj.get("order"),
            "is_expanded": obj.get("is_expanded"),
            "content": Content.from_dict(obj["content"]) if obj.get("content") is not None else None
        })
        return _obj


